@@ -1,14 +1,14 @@
 ﻿from captcha.conf import settings
-from django.conf import settings as django_settings
 from captcha.models import CaptchaStore, get_safe_now
 from django.core.exceptions import ImproperlyConfigured
-from django.core.urlresolvers import reverse,  NoReverseMatch
+from django.core.urlresolvers import reverse, NoReverseMatch
 from django.forms import ValidationError
 from django.forms.fields import CharField, MultiValueField
 from django.forms.widgets import TextInput, MultiWidget, HiddenInput
 from django.utils.translation import ugettext, ugettext_lazy
 from six import u
 
+
 class BaseCaptchaTextInput(MultiWidget):
     """
     Base class for Captcha widgets
@@ -42,11 +42,6 @@ class BaseCaptchaTextInput(MultiWidget):
         self._key = key
         self.id_ = self.build_attrs(attrs).get('id', None)
 
-    def render(self, name, value, attrs=None):
-        #self.fetch_captcha_store(name, value, attrs)
-        attrs.update(dict(autocomplete='off'))
-        return super(BaseCaptchaTextInput, self).render(name, self._value, attrs=attrs)
-
     def id_for_label(self, id_):
         if id_:
             return id_ + '_1'
@@ -66,6 +61,7 @@ class CaptchaTextInput(BaseCaptchaTextInput):
     def __init__(self, attrs=None, **kwargs):
         self._args = kwargs
         self._args['output_format'] = self._args.get('output_format') or settings.CAPTCHA_OUTPUT_FORMAT
+        self._args['id_prefix'] = self._args.get('id_prefix')
 
         for key in ('image', 'hidden_field', 'text_field'):
             if '%%(%s)s' % key not in self._args['output_format']:
@@ -75,8 +71,21 @@ class CaptchaTextInput(BaseCaptchaTextInput):
                 ))
         super(CaptchaTextInput, self).__init__(attrs)
 
+    def build_attrs(self, extra_attrs=None, **kwargs):
+        ret = super(CaptchaTextInput, self).build_attrs(extra_attrs, **kwargs)
+        if self._args.get('id_prefix') and 'id' in ret:
+            ret['id'] = '%s_%s' % (self._args.get('id_prefix'), ret['id'])
+        return ret
+
+    def id_for_label(self, id_):
+        ret = super(CaptchaTextInput, self).id_for_label(id_)
+        if self._args.get('id_prefix') and 'id' in ret:
+            ret = '%s_%s' % (self._args.get('id_prefix'), ret)
+        return ret
+
     def format_output(self, rendered_widgets):
         hidden_field, text_field = rendered_widgets
+        text_field = text_field.replace('<input', '<input autocomplete="off"')
         return self._args['output_format'] % {
             'image': self.image_and_audio,
             'hidden_field': hidden_field,
@@ -89,8 +98,6 @@ class CaptchaTextInput(BaseCaptchaTextInput):
         self.image_and_audio = '<img src="%s" alt="captcha" class="captcha" />' % self.image_url()
         if settings.CAPTCHA_FLITE_PATH:
             self.image_and_audio = '<a href="%s" title="%s">%s</a>' % (self.audio_url(), ugettext('Play CAPTCHA as audio file'), self.image_and_audio)
-
-
         return super(CaptchaTextInput, self).render(name, self._value, attrs=attrs)
 
 
@@ -105,7 +112,10 @@ class CaptchaField(MultiValueField):
                 kwargs['error_messages'] = {}
             kwargs['error_messages'].update({'invalid': ugettext_lazy('Invalid CAPTCHA')})
 
-        kwargs['widget'] = kwargs.pop('widget', CaptchaTextInput(output_format=kwargs.pop('output_format', None)))
+        kwargs['widget'] = kwargs.pop('widget', CaptchaTextInput(
+            output_format=kwargs.pop('output_format', None),
+            id_prefix=kwargs.pop('id_prefix', None)
+        ))
 
         super(CaptchaField, self).__init__(fields, *args, **kwargs)
 
