@@ -2,7 +2,6 @@ from captcha.conf import settings
 from captcha.helpers import captcha_image_url
 from captcha.models import CaptchaStore
 from django.http import HttpResponse, Http404
-from django.shortcuts import get_object_or_404
 import random
 import re
 import tempfile
@@ -38,8 +37,21 @@ def getsize(font, text):
         return font.getsize(text)
 
 
+def makeimg(size):
+    if settings.CAPTCHA_BACKGROUND_COLOR == "transparent":
+        image = Image.new('RGBA', size)
+    else:
+        image = Image.new('RGB', size, settings.CAPTCHA_BACKGROUND_COLOR)
+    return image
+
+
 def captcha_image(request, key, scale=1):
-    store = get_object_or_404(CaptchaStore, hashkey=key)
+    try:
+        store = CaptchaStore.objects.get(hashkey=key)
+    except CaptchaStore.DoesNotExist:
+        # HTTP 410 Gone status so that crawlers don't index these expired urls.
+        return HttpResponse(status=410)
+
     text = store.challenge
 
     if settings.CAPTCHA_FONT_PATH.lower().strip().endswith('ttf'):
@@ -47,9 +59,13 @@ def captcha_image(request, key, scale=1):
     else:
         font = ImageFont.load(settings.CAPTCHA_FONT_PATH)
 
-    size = getsize(font, text)
-    size = (size[0] * 2, int(size[1] * 1.4))
-    image = Image.new('RGB', size, settings.CAPTCHA_BACKGROUND_COLOR)
+    if settings.CAPTCHA_IMAGE_SIZE:
+        size = settings.CAPTCHA_IMAGE_SIZE
+    else:
+        size = getsize(font, text)
+        size = (size[0] * 2, int(size[1] * 1.4))
+
+    image = makeimg(size)
 
     try:
         PIL_VERSION = int(NON_DIGITS_RX.sub('', Image.VERSION))
@@ -81,7 +97,13 @@ def captcha_image(request, key, scale=1):
         image = Image.composite(fgimage, image, maskimage)
         xpos = xpos + 2 + charimage.size[0]
 
-    image = image.crop((0, 0, xpos + 1, size[1]))
+    if settings.CAPTCHA_IMAGE_SIZE:
+        # centering captcha on the image
+        tmpimg = makeimg(size)
+        tmpimg.paste(image, (int((size[0] - xpos) / 2), int((size[1] - charimage.size[1]) / 2 - from_top)))
+        image = tmpimg.crop((0, 0, size[0], size[1]))
+    else:
+        image = image.crop((0, 0, xpos + 1, size[1]))
     draw = ImageDraw.Draw(image)
 
     for f in settings.noise_functions():
@@ -102,7 +124,12 @@ def captcha_image(request, key, scale=1):
 
 def captcha_audio(request, key):
     if settings.CAPTCHA_FLITE_PATH:
-        store = get_object_or_404(CaptchaStore, hashkey=key)
+        try:
+            store = CaptchaStore.objects.get(hashkey=key)
+        except CaptchaStore.DoesNotExist:
+            # HTTP 410 Gone status so that crawlers don't index these expired urls.
+            return HttpResponse(status=410)
+
         text = store.challenge
         if 'captcha.helpers.math_challenge' == settings.CAPTCHA_CHALLENGE_FUNCT:
             text = text.replace('*', 'times').replace('-', 'minus')
